@@ -1,3 +1,5 @@
+from typing import Optional
+
 import torch
 import torch.nn as nn
 import torch.nn.functional as F
@@ -25,13 +27,17 @@ class SoftmaxLoss(GroupLoss):
         self.kernel = nn.Parameter(torch.FloatTensor(embedding_size, num_groups))
         nn.init.normal_(self.kernel, std=0.01)
 
-    def forward(self, embeddings: Tensor, groups: LongTensor) -> Tensor:
+    def forward(
+        self,
+        embeddings: Tensor,
+        groups: LongTensor,
+    ) -> Tensor:
         """Compute loss value.
 
         Args:
             embeddings: shape: (batch_size, vector_length) - Output embeddings from the
-                encoder.
-            groups: shape: (batch_size,) - Group ids, associated with embeddings.
+                encoder
+            groups: shape: (batch_size,) - Group ids, associated with embeddings
 
         Returns:
             Tensor: zero-size tensor, loss value
